// Copyright 2020 Google LLC.
// Use of this source code is governed by a BSD-style
// license that can be found in the LICENSE file.

// Package idtoken provides utilities for creating authenticated transports with
// ID Tokens for Google HTTP APIs. It also provides methods to validate Google
// issued ID tokens.
package idtoken
